@@ -1,4 +1,4 @@
-# Copyright (c) 2020 CNES
+# Copyright (c) 2021 CNES
 #
 # All rights reserved. Use of this source code is governed by a
 # BSD-style license that can be found in the LICENSE file.
@@ -10,9 +10,9 @@ Get software version information
 
 def release() -> str:
     """Returns the software version number"""
-    return "0.4.0"
+    return "0.8.0"
 
 
 def date() -> str:
     """Returns the creation date of this release"""
-    return "22 September 2020"
+    return "30 August 2021"
